@@ -11,8 +11,8 @@ _loggers = {
 
 
 class Ctx(object):
-    def __init__(self, auth: str = '', state: typing.Dict = {}):
-        self.__setattr__('_state', state)
+    def __init__(self, auth: str = ''):
+        super().__setattr__('_state', {})
         self.uid = str(uuid.uuid4())
         self.cid = 'unknown'
         self.kid = 'unknown'
